==> libakonadi5-23.08.5-2-armv7h.pkg.tar.xz: usr/lib/cmake/KF5Akonadi/KPim5AkonadiTargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5::AkonadiPrivate" for configuration ""
set_property(TARGET KF5::AkonadiPrivate APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::AkonadiPrivate PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPim5AkonadiPrivate.so.5.24.5"
  IMPORTED_SONAME_NOCONFIG "libKPim5AkonadiPrivate.so.5"
  )

list(APPEND _cmake_import_check_targets KF5::AkonadiPrivate )
list(APPEND _cmake_import_check_files_for_KF5::AkonadiPrivate "${_IMPORT_PREFIX}/lib/libKPim5AkonadiPrivate.so.5.24.5" )

# Import target "KF5::AkonadiCore" for configuration ""
set_property(TARGET KF5::AkonadiCore APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::AkonadiCore PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::KIOCore;KF5::I18n;KF5::IconThemes;KF5::ConfigCore;KF5::AkonadiPrivate"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPim5AkonadiCore.so.5.24.5"
  IMPORTED_SONAME_NOCONFIG "libKPim5AkonadiCore.so.5"
  )

list(APPEND _cmake_import_check_targets KF5::AkonadiCore )
list(APPEND _cmake_import_check_files_for_KF5::AkonadiCore "${_IMPORT_PREFIX}/lib/libKPim5AkonadiCore.so.5.24.5" )

# Import target "KF5::AkonadiAgentBase" for configuration ""
set_property(TARGET KF5::AkonadiAgentBase APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::AkonadiAgentBase PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::AkonadiPrivate;KF5::AkonadiWidgets;KF5::I18n"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPim5AkonadiAgentBase.so.5.24.5"
  IMPORTED_SONAME_NOCONFIG "libKPim5AkonadiAgentBase.so.5"
  )

list(APPEND _cmake_import_check_targets KF5::AkonadiAgentBase )
list(APPEND _cmake_import_check_files_for_KF5::AkonadiAgentBase "${_IMPORT_PREFIX}/lib/libKPim5AkonadiAgentBase.so.5.24.5" )

# Import target "KF5::AkonadiWidgets" for configuration ""
set_property(TARGET KF5::AkonadiWidgets APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::AkonadiWidgets PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::KIOCore;KF5::I18n;KF5::IconThemes;KF5::XmlGui;KF5::AkonadiPrivate"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPim5AkonadiWidgets.so.5.24.5"
  IMPORTED_SONAME_NOCONFIG "libKPim5AkonadiWidgets.so.5"
  )

list(APPEND _cmake_import_check_targets KF5::AkonadiWidgets )
list(APPEND _cmake_import_check_files_for_KF5::AkonadiWidgets "${_IMPORT_PREFIX}/lib/libKPim5AkonadiWidgets.so.5.24.5" )

# Import target "KF5::AkonadiXml" for configuration ""
set_property(TARGET KF5::AkonadiXml APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::AkonadiXml PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPim5AkonadiXml.so.5.24.5"
  IMPORTED_SONAME_NOCONFIG "libKPim5AkonadiXml.so.5"
  )

list(APPEND _cmake_import_check_targets KF5::AkonadiXml )
list(APPEND _cmake_import_check_files_for_KF5::AkonadiXml "${_IMPORT_PREFIX}/lib/libKPim5AkonadiXml.so.5.24.5" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> libakonadi-23.04.1-1-armv7h.pkg.tar.xz: usr/lib/cmake/KF5Akonadi/KPim5AkonadiTargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5::AkonadiPrivate" for configuration ""
set_property(TARGET KF5::AkonadiPrivate APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::AkonadiPrivate PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPim5AkonadiPrivate.so.5.23.1"
  IMPORTED_SONAME_NOCONFIG "libKPim5AkonadiPrivate.so.5"
  )

list(APPEND _cmake_import_check_targets KF5::AkonadiPrivate )
list(APPEND _cmake_import_check_files_for_KF5::AkonadiPrivate "${_IMPORT_PREFIX}/lib/libKPim5AkonadiPrivate.so.5.23.1" )

# Import target "KF5::AkonadiCore" for configuration ""
set_property(TARGET KF5::AkonadiCore APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::AkonadiCore PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::KIOCore;KF5::I18n;KF5::IconThemes;KF5::ConfigCore;KF5::AkonadiPrivate"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPim5AkonadiCore.so.5.23.1"
  IMPORTED_SONAME_NOCONFIG "libKPim5AkonadiCore.so.5"
  )

list(APPEND _cmake_import_check_targets KF5::AkonadiCore )
list(APPEND _cmake_import_check_files_for_KF5::AkonadiCore "${_IMPORT_PREFIX}/lib/libKPim5AkonadiCore.so.5.23.1" )

# Import target "KF5::AkonadiAgentBase" for configuration ""
set_property(TARGET KF5::AkonadiAgentBase APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::AkonadiAgentBase PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::AkonadiPrivate;KF5::AkonadiWidgets;KF5::I18n;KAccounts"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPim5AkonadiAgentBase.so.5.23.1"
  IMPORTED_SONAME_NOCONFIG "libKPim5AkonadiAgentBase.so.5"
  )

list(APPEND _cmake_import_check_targets KF5::AkonadiAgentBase )
list(APPEND _cmake_import_check_files_for_KF5::AkonadiAgentBase "${_IMPORT_PREFIX}/lib/libKPim5AkonadiAgentBase.so.5.23.1" )

# Import target "KF5::AkonadiWidgets" for configuration ""
set_property(TARGET KF5::AkonadiWidgets APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::AkonadiWidgets PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::KIOCore;KF5::I18n;KF5::IconThemes;KF5::XmlGui;KF5::AkonadiPrivate"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPim5AkonadiWidgets.so.5.23.1"
  IMPORTED_SONAME_NOCONFIG "libKPim5AkonadiWidgets.so.5"
  )

list(APPEND _cmake_import_check_targets KF5::AkonadiWidgets )
list(APPEND _cmake_import_check_files_for_KF5::AkonadiWidgets "${_IMPORT_PREFIX}/lib/libKPim5AkonadiWidgets.so.5.23.1" )

# Import target "KF5::AkonadiXml" for configuration ""
set_property(TARGET KF5::AkonadiXml APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::AkonadiXml PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPim5AkonadiXml.so.5.23.1"
  IMPORTED_SONAME_NOCONFIG "libKPim5AkonadiXml.so.5"
  )

list(APPEND _cmake_import_check_targets KF5::AkonadiXml )
list(APPEND _cmake_import_check_files_for_KF5::AkonadiXml "${_IMPORT_PREFIX}/lib/libKPim5AkonadiXml.so.5.23.1" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
